==> jc-1.4.0.tar.gz: javax/swing/text/AbstractDocument__243.h <==
// final class javax.swing.text.AbstractDocument$3

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 12864f5604c9fe77 javax_swing_text_AbstractDocument__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_AbstractDocument__243_H_
#define _JC_javax_swing_text_AbstractDocument__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_AbstractDocument$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__243$sub_refs	_jc_javax_swing_text_AbstractDocument__243$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__243$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$refs	_jc_javax_swing_text_AbstractDocument__243$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$nonrefs	_jc_javax_swing_text_AbstractDocument__243$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$object	_jc_javax_swing_text_AbstractDocument__243$object;

typedef const struct _jc_javax_swing_text_AbstractDocument__243$vmethods	_jc_javax_swing_text_AbstractDocument__243$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__243$vtable	_jc_javax_swing_text_AbstractDocument__243$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__243$vtype	_jc_javax_swing_text_AbstractDocument__243$vtype;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__243$method$_init$1be79448f63cb946(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *, struct _jc_javax_swing_text_AbstractDocument$object *);

// Virtual methods
extern jint _jc_javax_swing_text_AbstractDocument__243$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__243$method_info$getOffset$520eb02cb0855546;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__243$vmethods {
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *);
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_AbstractDocument__243$vmethods	javax_swing_text_AbstractDocument__243;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__243$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__243$sub_refs {
	struct _jc_javax_swing_text_AbstractDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__243$refs {
    _jc_javax_swing_text_AbstractDocument__243$sub_refs	javax_swing_text_AbstractDocument__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs	javax_swing_text_AbstractDocument__243;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__243$object {
	_jc_javax_swing_text_AbstractDocument__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__243$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__243$vtype _jc_javax_swing_text_AbstractDocument__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__243$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__243_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/AbstractDocument__243.h <==
// final class javax.swing.text.AbstractDocument$3

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ba5f60f3afa70974 javax_swing_text_AbstractDocument__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_AbstractDocument__243_H_
#define _JC_javax_swing_text_AbstractDocument__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_AbstractDocument$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__243$sub_refs	_jc_javax_swing_text_AbstractDocument__243$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__243$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$refs	_jc_javax_swing_text_AbstractDocument__243$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$nonrefs	_jc_javax_swing_text_AbstractDocument__243$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__243$object	_jc_javax_swing_text_AbstractDocument__243$object;

typedef const struct _jc_javax_swing_text_AbstractDocument__243$vmethods	_jc_javax_swing_text_AbstractDocument__243$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__243$vtable	_jc_javax_swing_text_AbstractDocument__243$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__243$vtype	_jc_javax_swing_text_AbstractDocument__243$vtype;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__243$method$_init$1be79448f63cb946(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *, struct _jc_javax_swing_text_AbstractDocument$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_text_AbstractDocument__243$method$getOffset$520eb02cb0855546(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__243$method_info$getOffset$520eb02cb0855546;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__243$vmethods {
	jint	(*getOffset$520eb02cb0855546)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__243$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_AbstractDocument__243$vmethods	javax_swing_text_AbstractDocument__243;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__243$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__243$sub_refs {
	struct _jc_javax_swing_text_AbstractDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__243$refs {
    _jc_javax_swing_text_AbstractDocument__243$sub_refs	javax_swing_text_AbstractDocument__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_AbstractDocument__243$sub_nonrefs	javax_swing_text_AbstractDocument__243;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__243$object {
	_jc_javax_swing_text_AbstractDocument__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__243$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__243$vtype _jc_javax_swing_text_AbstractDocument__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__243$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__243_H_ */
